==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Widgets/CadToolMatrix/ts/CadToolMatrix_sk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk">
<context>
    <name>CadToolMatrix</name>
    <message>
        <location filename="../CadToolMatrix.js" line="+366"/>
        <source>Expand all</source>
        <translation>Rozbaliť všetko</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Collapse all</source>
        <translation>Zbaliť všetko</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>List View</source>
        <translation>Zoznam</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Icon View</source>
        <translation>Ikony</translation>
    </message>
    <message>
        <location line="+34"/>
        <source>Widgets</source>
        <translation>Pomôcky</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+48"/>
        <source>Tool Matrix</source>
        <translation>Matrica nástrojov</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Icon Size:</source>
        <translation>Veľkosť ikony:</translation>
    </message>
    <message>
        <location line="+96"/>
        <source>Pixel</source>
        <translation>Pixel</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>List view</source>
        <translation>Zoznam</translation>
    </message>
</context>
<context>
    <name>ToolMatrixWidget</name>
    <message>
        <location filename="../CadToolMatrix.ui" line="+37"/>
        <source>Filter</source>
        <translation>Filter</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Widgets/CadToolMatrix/ts/CadToolMatrix_sk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk">
<context>
    <name>CadToolMatrix</name>
    <message>
        <location filename="../CadToolMatrix.js" line="+373"/>
        <source>Expand all</source>
        <translation>Rozbaliť všetko</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Collapse all</source>
        <translation>Zbaliť všetko</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>List View</source>
        <translation>Zoznam Pohľadov</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Icon View</source>
        <translation>Ikony</translation>
    </message>
    <message>
        <location line="+34"/>
        <source>Widgets</source>
        <translation>Pomôcky</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+48"/>
        <source>Tool Matrix</source>
        <translation>Matrica nástrojov</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Icon Size:</source>
        <translation>Veľkosť ikony:</translation>
    </message>
    <message>
        <location line="+96"/>
        <source>Pixel</source>
        <translation>Pixel</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>List view</source>
        <translation>Zoznam pohľadov</translation>
    </message>
</context>
<context>
    <name>ToolMatrixWidget</name>
    <message>
        <location filename="../CadToolMatrix.ui" line="+37"/>
        <source>Filter</source>
        <translation>Filter</translation>
    </message>
</context>
</TS>
